@@ -43,6 +43,9 @@
  *		      meta_decode (only follow subspaces, ignore data) and 
  *		      meta_buildtree/meta_encode (ignore), resp. This
  *		      obsoletes the MT_IGNORE data type.
+ * 2002/12/12 - EvB - Fixed incorrect behaviour of meta_getitemby*, which used
+ * 		      META_ORD_ERR as a wildcard for vendor numbers; introduced
+ * 		      META_VND_WILD for that purpose instead.
  */
 
 char metadata_id[] = "METADATA - Copyright (C) 2000 Emile van Bergen.";
@@ -378,29 +381,38 @@ META_ITEM *meta_additem(META *m, META_SPC *s,
 
 
 /* Find an item by its number, given a space and vendor number.
-   A vendor number of META_ORD_ERR means any vendor number. */
+   A vendor number of META_VND_WILD means any vendor number. */
 
 META_ITEM *meta_getitembynr(META *m, META_SPC *s, META_ORD nr, META_ORD vnd)
 {
 	META_ITEM *ret;
 
-	if (vnd != META_ORD_ERR) {
+	ret = 0;
+	if (s) {
+		if (vnd != META_VND_WILD) {
+
+			for(ret = s->items;
+			    ret && (ret->nr != nr || ret->vnd != vnd);
+			    ret = ret->next);
+			return ret;
+		}
 
 		for(ret = s->items;
-		    ret && (ret->nr != nr || ret->vnd != vnd);
+		    ret && ret->nr != nr;
 		    ret = ret->next);
+
 		return ret;
 	}
 
-	for(ret = s->items;
-	    ret && ret->nr != nr;
-	    ret = ret->next);
+	for(s = m->spaces; 
+	    s && !(ret = meta_getitembynr(m, s, nr, vnd));
+	    s = s->next);
 	return ret;
 }
 
 
 /* Find an item by its name in a space, or in all spaces if s == 0.
-   A vendor number of META_ORD_ERR means any vendor number. */
+   A vendor number of META_VND_WILD means any vendor number. */
 
 META_ITEM *meta_getitembyname(META *m, META_SPC *s, char *name, META_ORD vnd)
 {
@@ -408,7 +420,7 @@ META_ITEM *meta_getitembyname(META *m, META_SPC *s, char *name, META_ORD vnd)
 
 	ret = 0;
 	if (s) {
-		if (vnd != META_ORD_ERR) {
+		if (vnd != META_VND_WILD) {
 			for(ret = s->items;
 			    ret && (strcmp(ret->name, name) || ret->vnd != vnd);
 			    ret = ret->next);
@@ -419,11 +431,10 @@ META_ITEM *meta_getitembyname(META *m, META_SPC *s, char *name, META_ORD vnd)
 		    ret = ret->next);
 		return ret;
 	}
-	else {
-		for(s = m->spaces; 
-		    s && !(ret = meta_getitembyname(m, s, name, vnd));
-		    s = s->next);
-	}
+
+	for(s = m->spaces; 
+	    s && !(ret = meta_getitembyname(m, s, name, vnd));
+	    s = s->next);
 	return ret;
 }
 
@@ -439,7 +450,7 @@ META_ITEM *meta_getitembyspec(META *m, char *spec)
 	char *c;
 
 	/* Set defaults: all spaces, any vendor */
-	s = 0; vnd = META_ORD_ERR;
+	s = 0; vnd = META_VND_WILD;
 
 	/* Check if we have a colon */
 	c = strchr(spec, ':'); 
