@@ -258,9 +258,9 @@ static int setopt(META *m, struct set_options *opts, char *optval)
 						ord, opts->vendor))) return 0;
 
 		if ((opts->item = meta_getitembyname(m, opts->spc, 
-						arg, META_ORD_ERR))) return 0;
+						arg, META_VND_WILD))) return 0;
 		if ((opts->item = meta_getitembynr(m, opts->spc, 
-						ord, META_ORD_ERR))) return 0;
+						ord, META_VND_WILD))) return 0;
 
 		if ((opts->item = meta_getitembyname(m, 0,
 						arg, opts->vendor))) return 0;
@@ -268,9 +268,9 @@ static int setopt(META *m, struct set_options *opts, char *optval)
 						ord, opts->vendor))) return 0;
 
 		if ((opts->item = meta_getitembyname(m, 0,
-						arg, META_ORD_ERR))) return 0;
+						arg, META_VND_WILD))) return 0;
 		if ((opts->item = meta_getitembynr(m, 0,
-						ord, META_ORD_ERR))) return 0;
+						ord, META_VND_WILD))) return 0;
 
 		msg(F_TEXT, L_ERR, "dict_setopt: ERROR: Unknown item '%s'!\n",
 		    arg);
@@ -417,8 +417,8 @@ META *meta_newfromdict(char *basepath)
 				goto meta_newfromdict_err;
 			}
 
-			msg(F_TEXT, L_NOTICE, "meta_newfromdict: including '%s'"
-					      " from '%s', line %d.\n", 
+			msg(F_TEXT, L_DEBUG, "meta_newfromdict: including '%s'"
+					     " from '%s', line %d.\n", 
 			    word, text_fname(t), linenr);
 
 			if (text_include(t, word) == -1) {
