@@ -44,6 +44,10 @@
  * 		      source list now.
  * 2002/04/03 - EvB - Good cleanup of buildtree(). It also leaves the source 
  * 		      list intact now, so that you can re-use parts of it.
+ * 2002/12/12 - EvB - Fixed incorrect search for attributes from any vendor
+ * 		      instead of attributes with vendor nr. META_ORD_ERR if
+ * 		      no attribute with the correct vendor is found in 
+ * 		      meta_decode.
  */
 
 char metaops_id[] = "METAOPS - Copyright (C) 2001 Emile van Bergen.";
@@ -217,8 +221,8 @@ META_AV *meta_decode(META *m, META_SPC *s, META_ORD defvnd,
 		/* Test here if the space doesn't have any items and tell about
 		   it. Otherwise we'd also return 0 but without telling why. */
 		if (!s->items) {
-			msg(F_RECV, L_DEBUG, "meta_decode: ERROR: Space %s "
-					     "does not contain any fields!\n",
+			msg(F_RECV, L_ERR, "meta_decode: ERROR: Space %s "
+					   "does not contain any fields!\n",
 			    s->name);
 			return 0;
 		}
