@@ -371,14 +371,14 @@ ssize_t ring_count(RING *r, RINGCNTFUNC func, ...)
 
 			/* peek at single part, return whatever the
 			   closure returns. */
-			return func(r->buf + r->r, len, ap);
+			return func(r->buf + r->r, len, 0, ap);
 		}
 		else {
 
 			/* Message doesn't end before end of buffer */
 
 			/* peek at first part, till end of buffer */
-			ret = func(r->buf + r->r, r->size - r->r, ap);
+			ret = func(r->buf + r->r, r->size - r->r, 0, ap);
 
 			if (ret < r->size - r->r) {
 				/* Satisfied by first part; return whatever
@@ -387,7 +387,8 @@ ssize_t ring_count(RING *r, RINGCNTFUNC func, ...)
 			}
 
 			/* peek at rest, from start of buffer */
-			return ret + func(r->buf, len - (r->size - r->r), ap);
+			return ret + func(r->buf, len - (r->size - r->r), 
+					  ret, ap);
 		}
 	}
 
@@ -398,7 +399,7 @@ ssize_t ring_count(RING *r, RINGCNTFUNC func, ...)
 
 /* count functions for ring_str(c)spn - varargs: char *s, int slen. */
 
-ssize_t _ring_cnt_strspn(char *s, ssize_t len, va_list ap)
+ssize_t _ring_cnt_strspn(char *s, ssize_t len, ssize_t seen, va_list ap)
 {
 	char *set;
 	int setlen;
@@ -412,7 +413,7 @@ ssize_t _ring_cnt_strspn(char *s, ssize_t len, va_list ap)
 	return ret;
 }
 
-ssize_t _ring_cnt_strcspn(char *s, ssize_t len, va_list ap)
+ssize_t _ring_cnt_strcspn(char *s, ssize_t len, ssize_t seen, va_list ap)
 {
 	char *set;
 	int setlen;
@@ -426,13 +427,13 @@ ssize_t _ring_cnt_strcspn(char *s, ssize_t len, va_list ap)
 	return ret;
 }
 
-ssize_t _ring_cnt_strncmp(char *s, ssize_t len, va_list ap)
+ssize_t _ring_cnt_strncmp(char *s, ssize_t len, ssize_t seen, va_list ap)
 {
 	char *arg;
 	ssize_t arglen;
 
-	arg = va_arg(ap, char *);
-	arglen = va_arg(ap, ssize_t);
+	arg = va_arg(ap, char *) + seen;
+	arglen = va_arg(ap, ssize_t) - seen;
 
 	/* arglen is smallest - compare arglen, return that or nothing */
 	if (arglen <= len)
