@@ -17,6 +17,8 @@ int main()
 	META_AV *avhead, *avtail, *avtree;
 	int len;
 
+	msg_init(-1, 0);
+
 	m = meta_newfromdict("../../raddb");
 	if (!m) { msg(F_MISC, L_ERR,"main: ERROR: Couldn't open dictionary!\n");
 		  return 1; }
@@ -38,7 +40,7 @@ int main()
 	meta_printavlist(m, avhead, 0);
 
 	/* Buildtree using base space RAD_PKT */
-	meta_buildtree(&avhead, &avtree, spc);
+	meta_buildtree(avhead, &avtree, spc);
 	write(2, "A/V tree:\n", 10);
 	meta_printavlist(m, avtree, 0);
 	meta_freeavlist(avhead); avhead = avtail = 0;
