@@ -41,6 +41,8 @@ char radiusd_id[] = "RADIUSD - Copyright (C) 2001 Emile van Bergen.";
 #include <jobs.h>		/* Also includes srvtypes.h */
 #include <channels.h>		/* For chan_handle_*; also includes subprocs */
 
+#include <defs.h>
+
 
 /*
  * GLOBALS
@@ -108,15 +110,8 @@ void parseoptions(int argc, char **argv)
 			n += 2;	    /* L_ERR to L_NOTICE to L_DEBUG */
 		  case 'd':
 			n += 2;	    /* L_ERR to L_NOTICE to L_DEBUG */
-			fac = msg_getfacbyname(optarg);
-			if (fac != F_INVAL) {
-				msg_setthresh(fac, n);
-				break;
-			}
-			/* If no valid facility was specified, set all */
-			for(fac = 0; fac < F_CNT; fac++) {
-				msg_setthresh(fac, n);
-			}
+			if (optarg && (fac = msg_getfacbyname(optarg)) != F_INVAL) { msg_setthresh(fac, n); break; }
+			for(fac = 0; fac < F_CNT; fac++) msg_setthresh(fac, n);
 			break;
 		  case 'b': nobackgr = 1; break;
 		  case 'v':
@@ -173,7 +168,7 @@ void sighandler(int sig)
 	sigaddset(&set, sig);
 	write(spipe[PIPE_W], &set, sizeof(set));
 
-#ifdef NO_SIGACTION
+#ifndef HAVE_SIGACTION
 	signal(sig, sighandler);
 #endif
 }
@@ -194,7 +189,7 @@ int main(int argc, char **argv)
 	PROC *p;
 	PROC_SET ps;
 	sigset_t sigs, oldsigs;
-#ifndef NO_SIGACTION
+#ifdef HAVE_SIGACTION
 	struct sigaction sa;
 #endif
 	fd_set rfds, wfds;
@@ -228,15 +223,15 @@ int main(int argc, char **argv)
 	}
 
 	/* Install handler */
-#ifdef NO_SIGACTION
-	signal(SIGHUP, sighandler); signal(SIGINT, sighandler);
-	signal(SIGQUIT, sighandler); signal(SIGTERM, sighandler); 
-	signal(SIGCHLD, sighandler);
-#else
+#ifdef HAVE_SIGACTION
 	sa.sa_flags = SA_NOCLDSTOP + SA_RESTART; sa.sa_handler = sighandler; 
 	sigaction(SIGHUP, &sa, 0); sigaction(SIGINT, &sa, 0);
 	sigaction(SIGQUIT, &sa, 0); sigaction(SIGTERM, &sa, 0);
 	sigaction(SIGCHLD, &sa, 0);
+#else
+	signal(SIGHUP, sighandler); signal(SIGINT, sighandler);
+	signal(SIGQUIT, sighandler); signal(SIGTERM, sighandler); 
+	signal(SIGCHLD, sighandler);
 #endif
 
 	/* Go to background */
